Glances
=======

.. image:: _static/screenshot-wide.png

Glances is a cross-platform monitoring tool which aims to present a
maximum of information in a minimum of space through a curses or Web
based interface. It can adapt dynamically the displayed information
depending on the terminal size.

It can also work in client/server mode. Remote monitoring could be
done via terminal, Web interface or API (XMLRPC and RESTful).

Glances is written in Python and uses the `psutil`_ library to get
information from your system.

Stats can also be exported to external time/value databases.

.. _psutil: https://github.com/giampaolo/psutil

Table of Contents
=================

.. toctree::
   :maxdepth: 2

   install
   quickstart
   cmds
   config
   aoa/index
   gw/index
   api
   docker
   faq
   support
